const aws = require("aws-sdk");
const Service = require("./base");
const config = require("../config");

class SES extends Service {
  constructor(region, recipients, log) {
    super();

    region = region || process.env.SES_AWS_REGION || process.env.AWS_REGION;
    recipients = recipients || process.env.SES_RECIPIENTS;
    log = log || config.log;

    if (!region) throw Error("AWS region is not set. Set it as an env var.");
    if (!recipients)
      throw Error(
        "SES recipients is not set. Set it as an env var separated with comma: `jperez@wiggot.com,progra@wiggot.com`."
      );

    this._region = region;
    this._recipients = recipients.split(",");
    this._ses = new aws.SES({ region: this._region });
    this.log = log;
  }

  //@override
  send(logBuffer) {
    const date = new Date();
    this._ses
      .sendEmail({
        Destination: {
          ToAddresses: this._recipients
        },
        Message: {
          Body: {
            Text: {
              Data: logBuffer.toString()
            }
          },
          Subject: {
            Data: `Error in ${config.serviceName} ${date.toISOString()}`
          }
        },
        Source: "bot@wiggot.com"
      })
      .promise()
      .then(() => {})
      .catch(() => {});
  }
}

module.exports = SES;
